import { select , geoMercator, json, geoPath, event,zoom } from 'd3';
const width = document.body.clientWidth;
const height = document.body.clientHeight;
const svg = select('svg').attr('width', width).attr('height', height);
const g = svg.append('g');
const mercator = geoMercator().scale(30000).translate([width/2, height/2]).center([73,19.7]);
const pathGenerator = geoPath().projection(mercator);
//Zoom
svg.call(zoom().on('zoom',() =>{
	g.attr('transform',event.transform)
}))

//Reading data
const render = data => {
  
// console.log(data);
let BlockValue  = d => d.properties.Block;
let StuntedValue = d => d.properties.Stunted ;
let SevStuntedValue = d => d.properties.SevStented ;
let StuntingPValue = d => d.properties.StuntingP ;
let UnderweightPValue = d => d.properties.UnderweightP ;
let LBWPValue = d => d.properties.LBWP ;

const min = d3.min(data,StuntedValue);
const max = d3.max(data,StuntedValue);
const comp = (max - min)/3;
// Define the div for the tooltip
const onMouseOver = d =>{	
tooltip.transition().duration(200).style("opacity", .9);		
tooltip.html("<b>"+d.properties.Block+"</b><br><b>Stunted child:</b>"+d.properties.Stunted)
    .style("left", d3.event.pageX + "px")
    .style("top",  d3.event.pageY - 30 + "px");	
}
 var tooltip = d3.select("body").append("div") 
        .attr("class", "tooltip")       
        .style("opacity", 0);

var myColor = v =>{
  if(v>=min && v < min + comp)
    return 'red';
  else if(v >= min+comp && v<max-comp)
    return 'yellow';
  else if(v >= max-comp)
    return 'green';
}
  
	const paths = g.selectAll('path').data(data)
  .enter().append('path').attr('d',pathGenerator).attr('class','my-block')
  .style("fill", function(d) {
      var value = d.properties.Stunted;
      return myColor(value);
		}).on("mouseover", d => onMouseOver(d))          
      .on("mouseout", function(d) {   
            tooltip.transition()    
            .duration(500)    
            .style("opacity", 0); 
          });
  
  
   g.selectAll("text").data(data)
    .enter().append("text")
    .text(d => d.properties.Block)
    .attr("x", function(d){
        return pathGenerator.centroid(d)[0];
    })
    .attr("y", function(d){
        return  pathGenerator.centroid(d)[1];
    })
    .attr("text-anchor","middle")
    .attr('font-size','12pt')
    .attr("font-family", "sans-serif");
}
const monthwise = (data) =>{
  
	let month = {'Aug':[],'Sep':[],'Oct':[]}
  data.forEach(d=>{
  let temp = {};
  temp.block_n = d.block_n
  temp.mdrtly_stntd=+d.mdrtly_stntd
  temp.svrly_stntd=+d.svrly_stntd
  temp.stunting_percent=+d.stunting_percent
  temp.underweight_percent=+d.underweight_percent
  temp.low_birth_weight_percent=+d.low_birth_weight_percent
  month[d.month_n].push(temp)
    
  })
  // console.log(month);
return month;
  
}

const addProperty=(data,json)=>{
    for (var i = 0; i < data.length; i++) {
    	var dataBlock = data[i].block_n;
      var dataStunted = data[i].mdrtly_stntd;
      var dataSevStunted = data[i].svrly_stntd;
      var dataStuntingP = data[i].stunting_percent;
      var dataUnderweightP = data[i].underweight_percent;
      var dataLBWP = data[i].low_birth_weight_percent;
    for (var j = 0; j < json.features.length; j++)  {
        var jsonBlock = json.features[j].properties.Block;

        if (dataBlock == jsonBlock) {
        json.features[j].properties.Stunted = +dataStunted; 
        json.features[j].properties.SevStunted = +dataSevStunted; 
        json.features[j].properties.StuntingP = +dataStuntingP; 
        json.features[j].properties.UnderweightP = +dataUnderweightP; 
        json.features[j].properties.LBWP = +dataLBWP; 
        break;
      }
    }
    }
  return json.features
}
const monthwisejson = (monthwiseData) =>{
  json('block.geojson').then(json=>{
    console.log(json);
  let augJSON = addProperty(monthwiseData.Aug,json);
  let sepJSON = addProperty(monthwiseData.Sep,json);
  let octJSON = addProperty(monthwiseData.Oct,json);
  let jsonMonth = {'Aug':augJSON,'Sep':sepJSON,'Oct':octJSON}
   // console.log(jsonMonth);
  return jsonMonth;
   
  })
  
  
}
d3.csv("data_monthly.csv").then(data =>{
  // console.log(data);
	const monthwiseData = monthwise(data);

       
    const monthwiseJson = monthwisejson(monthwiseData);
    // render(monthwiseJson.Oct);




})

